# Potentiometer Test with RGB LED
# Tony Goodhew 9th April 2021
# MAKER Pi Pico board
# SSD1306 (128x64) on Grove port 4 GP6 & GP7
# 10K Ohm potentiometer on GP26 - ADC0
import board
import time
import digitalio
from analogio import AnalogIn
import busio as io
import adafruit_ssd1306
from neopixel_write import neopixel_write
RGB = digitalio.DigitalInOut(board.GP28)
RGB.direction = digitalio.Direction.OUTPUT

# Analog input pin (ADC0)
analog_in = AnalogIn(board.GP26) # 10K Ohm potentiometer

# Setup SSD1306 (128x64) I2C display with SCL = GP7, SDA = GP6
i2c = io.I2C(board.GP7, board.GP6)
oled = adafruit_ssd1306.SSD1306_I2C(128, 64, i2c)

# Initialize STOP button
button1 = digitalio.DigitalInOut(board.GP20)
button1.switch_to_input(pull=digitalio.Pull.UP)

def align(n, max_chars):
    # Aligns string of n in max_chars
    msg1 = str(n)
    space = max_chars - len(msg1)
    msg2 = ""
    for m in range(space):
        msg2 = msg2 +" "
    msg2 = msg2 + msg1
    return msg2  # String - ready for display

# Instruction screen
oled.fill(0)
oled.text("Turn the Pot", 30, 5, 1)
oled.text("Press left button", 14, 30, 1)
oled.text("to halt program", 20, 45, 1)
oled.show()
time.sleep(3)
oled.fill(0)
oled.show()
running = True
# ===== Main ==========
while running:
	# Clear screen
    oled.fill(0)
    # Read pot value
    v = analog_in.value
    # Adjust ADC range error
    v = v - 300
    if v < 0 : v = 0
    if v > 65220: v = 65220
    p = int((v * 100) /65220)

	# display corrected analog value
    oled.text('Analog pot = ', 12, 0, 1)
    oled.text(str(v), 90, 0, 1)
	
	# display voltage
    oled.text('Voltage = ', 20, 12, 1)
    oled.text(str(p * 3.3 /100), 80, 12, 1)
	
    # Draw bar graph on analog value
	# fill_rect(x, y, width, height, colour)
    oled.fill_rect(13, 25, 1, 20, 1)
    oled.fill_rect(14, 30, p, 10, 1)
    oled.text(align(p,4) +" %", 45, 44, 1)

	# Show colour on OLED
    # Calculate RGB LED colour
    if p < 50: # Blue -> Cyan -> Green
        r = 0
        g = int(p * 2)
        b = int(100 - p * 2)
    else:       # Green -. Yellow -> Red
        r = int((p-50)*2)
        g = int(100 - ((p-50)*2))
        b = 0
    # Set RGB LED colour - not too bright
    # Note colour order GRB ?
    neopixel_write(RGB, bytearray([g//5,r//5,b//5]))
    # Display colour values
    oled.text("R: "+str(r), 0, 54, 1)
    oled.text("G: "+str(g), 41, 54, 1)
    oled.text("B: "+str(b), 82, 54, 1)
    oled.show()
    # Check to Halt button press
    if button1.value == 0: # Pressed
        running = False

# === Tidy up ===
# Turn Neopixel OFF
neopixel_write(RGB, bytearray([0,0,0]))
# Clear screen
oled.fill(0)
oled.text("All Done", 40, 30, 1)
oled.show()
time.sleep(2)
oled.fill(0)
oled.show()